@@ -6,6 +6,7 @@
 use strict;
 use warnings;
 
+use File::Slurp; # For read_file().
 use File::Spec;
 
 use GraphViz2;
@@ -15,8 +16,6 @@ use Log::Handler;
 
 use Parse::RecDescent;
 
-use Perl6::Slurp;
-
 # ------------------------------------------------
 
 my($logger) = Log::Handler -> new;
@@ -40,7 +39,7 @@ my($graph) = GraphViz2 -> new
 	 node   => {color => 'blue', shape => 'oval'},
 	);
 my($g)      = GraphViz2::Parse::RecDescent -> new(graph => $graph);
-my $grammar = slurp(File::Spec -> catfile('t', 'sample.recdescent.1.dat') );
+my $grammar = read_file(File::Spec -> catfile('t', 'sample.recdescent.1.dat') );
 my($parser) = Parse::RecDescent -> new($grammar);
 
 $g -> create(name => 'Grammar', grammar => $parser);
